close all
clear
clc

%% ===== Init =====
N = 100000;
B = 1000;

T = 5;

alpha_0 = 0.2;
beta_0 = 1;

N_0 = N*(beta_0 + 1)/(alpha_0 + beta_0)/(alpha_0 + beta_0 + 1);
N_1 = N*alpha_0*beta_0/(alpha_0 + beta_0)/(alpha_0 + beta_0 + 1);

do_save = true;

%% ===== Find Optimal =====
[U_opt, q_opt, t_s_opt, treateds_opt] = find_optimal_over_time_alloc(B, N_0, N_1, T, alpha_0, beta_0);

assert(sum(treateds_opt/B*100) > 99.9)

%% ===== Plot =====
qs = zeros(1, T);
for t = 1: T
    qs(t) = q_opt(t);
end

fig = figure;
set(fig, 'Position', [100, 100, 350, 550])

%
subplot(2, 1, 2)
hold on

yyaxis left
bar(1:T, treateds_opt/B*100, 'LineWidth', 2)

xlabel('$t$', 'FontSize', 18, 'Interpreter', 'latex')
ylabel('% of budget spent', 'FontSize', 18)

yyaxis right

t_terminal = find(cumsum(treateds_opt/B*100) >= 99.9, 1);
plot(1:t_terminal, qs(1:t_terminal), 'o-')

scatter(t_s_opt, q_opt(t_s_opt), 'filled')

ylim([-0.01, max(qs(1:t_terminal)) + 1])
xlim([0, T + 1])
ylabel('$q(t)$', 'FontSize', 18, 'Interpreter', 'latex')

%
subplot(2, 1, 1)
hold on

histogram(betarnd(alpha_0, beta_0, 1, N), 30, 'FaceColor', 'k', 'FaceAlpha', 0.2, 'Normalization', 'countdensity')
xlabel('$p$', 'FontSize', 18, 'Interpreter', 'latex')
ylabel('$\mathcal{P}^0(p)$', 'FontSize', 18, 'Interpreter', 'latex')
% title(sprintf('$\\mathcal{P}^0 = \\mathrm{Beta}(\\alpha=%g, \\beta=%g)$', alpha_0, beta_0), 'FontSize', 18, 'Interpreter', 'latex')

if do_save
    exportgraphics(gcf, sprintf('figs/opt_over_time_alloc_b%g_alpha%g_beta%g.pdf', B/N, alpha_0, beta_0), 'ContentType', 'vector', 'BackgroundColor', 'none');
end

